@@ -1,11 +1,6 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2013      Adrian Draghici <draghici.adrian.b@gmail.com>
+// SPDX-FileCopyrightText: 2013 Adrian Draghici <draghici.adrian.b@gmail.com>
 //
 
 #ifndef MARBLE_GROUNDOVERLAYFRAME_H
@@ -44,24 +39,24 @@ public:
 
     void update();
 
-    virtual bool containsPoint( const QPoint &eventPos ) const;
+    bool containsPoint( const QPoint &eventPos ) const override;
 
-    virtual void dealWithItemChange( const SceneGraphicsItem *other );
+    void dealWithItemChange( const SceneGraphicsItem *other ) override;
 
-    virtual void move( const GeoDataCoordinates &source, const GeoDataCoordinates &destination );
+    void move( const GeoDataCoordinates &source, const GeoDataCoordinates &destination ) override;
 
     /**
      * @brief Provides information for downcasting a SceneGraphicsItem.
      */
-    virtual const char *graphicType() const;
+    const char *graphicType() const override;
 
 protected:
-    virtual void paint( GeoPainter *painter, const ViewportParams *viewport, const QString &layer );
-    virtual bool mousePressEvent( QMouseEvent *event );
-    virtual bool mouseMoveEvent( QMouseEvent *event );
-    virtual bool mouseReleaseEvent( QMouseEvent *event );
+    void paint( GeoPainter *painter, const ViewportParams *viewport, const QString &layer, int tileZoomLevel ) override;
+    bool mousePressEvent( QMouseEvent *event ) override;
+    bool mouseMoveEvent( QMouseEvent *event ) override;
+    bool mouseReleaseEvent( QMouseEvent *event ) override;
 
-    virtual void dealWithStateChange( SceneGraphicsItem::ActionState previousState );
+    void dealWithStateChange( SceneGraphicsItem::ActionState previousState ) override;
 private:
     GeoDataGroundOverlay *m_overlay;
     TextureLayer         *m_textureLayer;
